about summary refs log tree commit diff
path: root/io/utime.h
diff options
context:
space:
mode:
Diffstat (limited to 'io/utime.h')
-rw-r--r--io/utime.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/io/utime.h b/io/utime.h
index 003e64778a..9f2f569b11 100644
--- a/io/utime.h
+++ b/io/utime.h
@@ -39,10 +39,10 @@ struct utimbuf
     __time_t modtime;		/* Modification time.  */
   };
 
-/* Set the access and modification times of FILE to those given in TIMES.
-   If TIMES is NULL, set them to the current time.  */
+/* Set the access and modification times of FILE to those given in
+   *FILE_TIMES.  If FILE_TIMES is NULL, set them to the current time.  */
 extern int utime __P ((__const char *__file,
-		       __const struct utimbuf *__times));
+		       __const struct utimbuf *__file_times));
 
 __END_DECLS